Container class

Constructors

Container(String filename, Map<String, dynamic> manifest, Map<String, Container> containers)

Properties

containers → Map<String, Container>
final
embedded → List<Object>
final
enums ↔ Iterable<Enum>
latefinal
filename → String
final
hashCode → int
The hash code for this object.
no setterinherited
importTypedData ↔ bool
getter/setter pair
includes → Map<String, List<String>>
final
manifest → Map<String, dynamic>
final
messages ↔ Iterable<Message>
latefinal
nodes → List<Node>
final
objects ↔ Iterable<Object>
latefinal
requests ↔ Iterable<Request>
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(Map<String, Container> containers) → List<String>
Return resulting code, must be overridden.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited