Field class abstract

Implementers

Constructors

Field(Node node, String tag, dynamic manifest)

Properties

attribute → String
Get attribute declaration code
no setter
declaration → String
Get property declaration code
no setter
estimate → List<String>
Get estimate buffer size code
no setter
hashCode → int
The hash code for this object.
no setterinherited
initializer → String
Get initializer list declaration code
no setter
manifest → dynamic
final
name → String
final
nameEnsured → String
no setter
node → Node
final
optional → bool
final
pack → List<String>
Get pack data into buffer code
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter
static → bool
Get whether it has a fixed footprint (always fixed size in a buffer) or not
no setter
tag → String
final
type → String
no setter
unpack → List<String>
Get unpack data from the buffer code
no setter

Methods

estimator([String name = '']) → String
Return corresponding single operation code
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packer([String name = '']) → String
toString() → String
A string representation of this object.
inherited
unpacker([String name = '']) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromEntry(Node node, MapEntry<String, dynamic> entry, {bool parentIsArray = false}) → Field
Try to create a Node instance of corresponding type