Message class

Inheritance

Constructors

Message(Container container, String tag, List manifest)

Properties

container → Container
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
manifest → dynamic
finalinherited
messageObject ↔ Object
latefinal
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
finalinherited

Methods

embed(Object node) → void
Adds an embedded node to output its code
inherited
include(String filename, String name) → void
Adds a reference to import from another file
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output() → List<String>
Return resulting code, must be overridden.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited