ObjectField class

Inheritance

Constructors

ObjectField(Node node, String tag, Map<String, dynamic> manifest, {bool parentIsArray = false})

Properties

attribute → String
Get attribute declaration code
no setterinherited
declaration → String
Get property declaration code
no setterinherited
embeddedObject → Object
final
estimate → List<String>
Get estimate buffer size code
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initializer → String
Get initializer list declaration code
no setterinherited
manifest → dynamic
finalinherited
name → String
finalinherited
nameEnsured → String
no setterinherited
node → Node
finalinherited
optional → bool
finalinherited
pack → List<String>
Get pack data into buffer code
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setterinherited
static → bool
Get whether it has a fixed footprint (always fixed size in a buffer) or not
no setterinherited
tag → String
finalinherited
type → String
no setteroverride
unpack → List<String>
Get unpack data from the buffer code
no setterinherited

Methods

estimator([String name = '']) → String
Return corresponding single operation code
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output() → List<String>
packer([String name = '']) → String
override
toString() → String
A string representation of this object.
inherited
unpacker([String name = '']) → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited